/*
 * Sets the autodimlevel to the first parameter (ranging from 0.0 to 1.0)
 * or 0.0 if none is given.
 * This is used to make the screen as black as possible
 * when nobody is logged in (e.g. in the logoutHook)
 *
 * Compile with:
 * cc -O2 -object -s -Wall setautodimlevel.c -o setautodimlevel
 * or
 * cc -O2 -object -s -Wall -arch i386 -arch m68k setautodimlevel.c -o setautodimlevel
 *
 * (c) 1993 Marcel Waldvogel
 */

#include <stddef.h>
#include <libc.h>
#include <drivers/event_status_driver.h>

int main(int argc, char **argv)
{
  NXEventHandle evs;

  switch (fork())	/* Background */
  {
  case 0:
    /* Backgrounded child */
    /* Let the loginwindow set its defaults first */
    sleep(3);
    if ((evs = NXOpenEventStatus()) == NULL)
    {
      perror("NXOpenEventStatus");
      exit(1);
    }
    if (argc == 2)
      NXSetAutoDimBrightness(evs, atof(argv[1]));
    else
      NXSetAutoDimBrightness(evs, 0.0);
    NXCloseEventStatus(evs);
    return 0;
  case -1:
    /* Cannot fork */
    perror("fork");
    return 2;
  default:
    /* Parent quits to let the child be in background */
    return 0;
  }
}

